pub enum Variant {
Monoscale,
Multiscale {
scale: f64,
handedness: Handedness,
pfret: f64,
},
}Expand description
Whether to output a traditional Monoscale style neck with the same scale
across it’s entire width, or a modern Multiscale neck, with a shorter scale
along the treble side, also known as fan fret.
Variants
Monoscale
A traditional fretbaord where the same scale length is used all of the way across the fretboard.
Multiscale
A modern style of neck where there is a longer scale length along the bass side of the neck and a shorter scale along the treble side of the neck, allowing for more natural string tension, greater flexibility in tuning, and better ergonomics.
Implementations
Sourceimpl Variant
impl Variant
pub fn multi() -> Self
Sourcepub fn scale(&self) -> Option<f64>
pub fn scale(&self) -> Option<f64>
Return the treble side scale length if the neck is Multiscale, or else
None
Sourcepub fn handedness(&self) -> Option<Handedness>
pub fn handedness(&self) -> Option<Handedness>
Returns whether the resulting neck is right or left handed, or None if
the neck is Monoscale